pub(crate) fn extract_external_indexes(
object: &DatabaseObject,
) -> Vec<(Cluster, CreateIndexStatement<Raw>)>Expand description
Find all external indexes on an object. That is, any index that lives on a different cluster than the one where the main object is installed.